html {
	background: #f1f1f1;
	margin: 0 20px;
}

body {
	background: #fff;
	color: #444;
	font-family: "Open Sans", sans-serif;
	margin: 140px auto 25px;
	padding: 20px 20px 10px 20px;
	max-width: 700px;
	-webkit-font-smoothing: subpixel-antialiased;
	-webkit-box-shadow: 0 1px 3px rgba(0,0,0,0.13);
	box-shadow: 0 1px 3px rgba(0,0,0,0.13);
}

a {
	color: #0073aa;
	text-decoration: none;
}

a:hover {
	color: #00a0d2;
}

h1 {
	border-bottom: 1px solid #dedede;
	clear: both;
	color: #666;
	font-size: 24px;
	margin: 30px 0;
	padding: 0;
	padding-bottom: 7px;
	font-weight: normal;
}

h2 {
	font-size: 16px;
}

p, li, dd, dt {
	padding-bottom: 2px;
	font-size: 14px;
	line-height: 1.5;
}

code, .code {
	font-family: Consolas, Monaco, monospace;
}

ul, ol, dl {
	padding: 5px 5px 5px 22px;
}

a img {
	border:0
}
abbr {
	border: 0;
	font-variant: normal;
}

label {
	cursor: pointer;
}

#logo {
	margin: 6px 0 14px 0;
	border-bottom: none;
	text-align:center
}
#logo a {
	background-image: url(../images/w-logo-blue.png?ver=20131202);
	background-image: none, url(../images/wordpress-logo.svg?ver=20131107);
	-webkit-background-size: 84px;
	background-size: 84px;
	background-position: center top;
	background-repeat: no-repeat;
	color: #999;
	height: 84px;
	font-size: 20px;
	font-weight: normal;
	line-height: 1.3em;
	margin: -130px auto 25px;
	padding: 0;
	text-decoration: none;
	width: 84px;
	text-indent: -9999px;
	outline: none;
	overflow: hidden;
	display: block;
}
.step {
	margin: 20px 0 15px;
}
.step, th {
	text-align: left;
	padding: 0;
}
.language-chooser.wp-core-ui .step .button.button-large {
	height: 36px;
	vertical-align: middle;
	font-size: 14px;
}
textarea {
	border: 1px solid #dfdfdf;
	font-family: "Open Sans", sans-serif;
	width: 100%;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
}

.form-table {
	border-collapse: collapse;
	margin-top: 1em;
	width: 100%;
}

.form-table td {
	margin-bottom: 9px;
	padding: 10px 20px 10px 0;
	border-bottom: 8px solid #fff;
	font-size: 14px;
	vertical-align: top
}

.form-table th {
	font-size: 14px;
	text-align: left;
	padding: 16px 20px 10px 0;
	width: 140px;
	vertical-align: top;
}

.form-table code {
	line-height: 18px;
	font-size: 14px;
}

.form-table p {
	margin: 4px 0 0 0;
	font-size: 11px;
}

.form-table input {
	line-height: 20px;
	font-size: 15px;
	padding: 3px 5px;
	border: 1px solid #ddd;
	-webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,0.07);
	box-shadow: inset 0 1px 2px rgba(0,0,0,0.07);
}

input,
submit {
	font-family: "Open Sans", sans-serif;
}

.form-table input[type=text],
.form-table input[type=email],
.form-table input[type=url],
.form-table input[type=password] {
	width: 206px;
}

.form-table th p {
	font-weight: normal;
}

.form-table.install-success td {
	vertical-align: middle;
	padding: 16px 20px 10px 0;
}

.form-table.install-success td p {
	margin: 0;
	font-size: 14px;
}

.form-table.install-success td code {
	margin: 0;
	font-size: 18px;
}

#error-page {
	margin-top: 50px;
}

#error-page p {
	font-size: 14px;
	line-height: 18px;
	margin: 25px 0 20px;
}

#error-page code, .code {
	font-family: Consolas, Monaco, monospace;
}

#pass-strength-result {
	background-color: #eee;
	border-color: #ddd !important;
	border-style: solid;
	border-width: 1px;
	margin: 5px 5px 5px 0;
	padding: 5px;
	text-align: center;
	width: 200px;
	display: none;
}

#pass-strength-result.bad {
	background-color: #ffb78c;
	border-color: #ff853c !important;
}

#pass-strength-result.good {
	background-color: #ffec8b;
	border-color: #ffcc00 !important;
}

#pass-strength-result.short {
	background-color: #ffa0a0;
	border-color: #f04040 !important;
}

#pass-strength-result.strong {
	background-color: #c3ff88;
	border-color: #8dff1c !important;
}

.message {
	border: 1px solid #c00;
	padding: 0.5em 0.7em;
	margin: 5px 0 15px;
	background-color: #ffebe8;
}

/* rtl:ignore */
#dbname,
#uname,
#pwd,
#dbhost,
#prefix,
#user_login,
#admin_email,
#pass1,
#pass2 {
	direction: ltr;
}


/* localization */
body.rtl,
.rtl textarea,
.rtl input,
.rtl submit {
	font-family: Tahoma, sans-serif;
}

:lang(he-il) body.rtl,
:lang(he-il) .rtl textarea,
:lang(he-il) .rtl input,
:lang(he-il) .rtl submit {
	font-family: Arial, sans-serif;
}

@media only screen and (max-width: 799px) {
	body {
		margin-top: 115px;
	}
	#logo a {
		margin: -125px auto 30px;
	}
}

@media screen and ( max-width: 782px ) {

	.form-table {
		margin-top: 0;
	}

	.form-table th,
	.form-table td {
		display: block;
		width: auto;
		vertical-align: middle;
	}

	.form-table th {
		padding: 20px 0 0;
	}

	.form-table td {
		padding: 5px 0;
		border: 0;
		margin: 0;
	}

	textarea,
	input {
		font-size: 16px;
	}

	.form-table td input[type="text"],
	.form-table td input[type="email"],
	.form-table td input[type="url"],
	.form-table td input[type="password"],
	.form-table td select,
	.form-table td textarea,
	.form-table span.description {
		width: 100%;
		font-size: 16px;
		line-height: 1.5;
		padding: 7px 10px;
		display: block;
		max-width: none;
		-webkit-box-sizing: border-box;
		-moz-box-sizing: border-box;
		box-sizing: border-box;
	}

}

body.language-chooser {
	max-width: 300px;
}

.language-chooser select {
	padding: 8px;
	width: 100%;
	display: block;
	border: 1px solid #ddd;
	background-color: #fff;
	color: #32373c;
	font-size: 16px;
	font-family: Arial, sans-serif;
	font-weight: normal;
}

.language-chooser p {
	text-align: right;
}

.screen-reader-input,
.screen-reader-text {
	position: absolute;
	margin: -1px;
	padding: 0;
	height: 1px;
	width: 1px;
	overflow: hidden;
	clip: rect(0 0 0 0);
	border: 0;
}

.spinner {
	background: url(../images/spinner.gif) no-repeat;
	-webkit-background-size: 20px 20px;
	background-size: 20px 20px;
	visibility: hidden;
	opacity: 0.7;
	filter: alpha(opacity=70);
	width: 20px;
	height: 20px;
	margin: 2px 5px 0;
}

.step .spinner {
	display: inline-block;
	margin-top: 8px;
	margin-right: 15px;
	vertical-align: top;
}

/**
 * HiDPI Displays
 */
@media print,
  (-webkit-min-device-pixel-ratio: 1.25),
  (min-resolution: 120dpi) {

	.spinner {
		background-image: url(../images/spinner-2x.gif);
	}

}
