#wpbody-content #dashboard-widgets.columns-1 .postbox-container {
	width: 100%;
}

#wpbody-content #dashboard-widgets.columns-2 .postbox-container {
	width: 49.5%;
}

#wpbody-content #dashboard-widgets.columns-2 #postbox-container-2,
#wpbody-content #dashboard-widgets.columns-2 #postbox-container-3,
#wpbody-content #dashboard-widgets.columns-2 #postbox-container-4 {
	float: left;
	width: 50.5%;
}

#wpbody-content #dashboard-widgets.columns-3 .postbox-container {
	width: 33.5%;
}

#wpbody-content #dashboard-widgets.columns-3 #postbox-container-1 {
	width: 33%;
}

#wpbody-content #dashboard-widgets.columns-3 #postbox-container-3,
#wpbody-content #dashboard-widgets.columns-3 #postbox-container-4 {
	float: left;
}

#wpbody-content #dashboard-widgets.columns-4 .postbox-container {
	width: 25%;
}

#dashboard-widgets .postbox-container {
	width: 25%;
}

#dashboard-widgets-wrap .columns-3 #postbox-container-4 .empty-container {
	border: none !important;
}

.ie8 #wpbody-content #dashboard-widgets .postbox-container {
	width: 49.5%;
}

.ie8 #wpbody-content #dashboard-widgets #postbox-container-2,
.ie8 #wpbody-content #dashboard-widgets #postbox-container-3,
.ie8 #wpbody-content #dashboard-widgets #postbox-container-4 {
	float: left;
	width: 50.5%;
}

.ie8 #dashboard-widgets #postbox-container-3 .empty-container,
.ie8 #dashboard-widgets #postbox-container-4 .empty-container {
	border: 0 none;
	height: 0;
	min-height: 0;
}

/*------------------------------------------------------------------------------
  9.0 - Dashboard
------------------------------------------------------------------------------*/

#dashboard-widgets-wrap {
	overflow: hidden;
	margin: 0 -8px;
}

#dashboard-widgets .postbox .inside {
	margin-bottom: 0;
}

#dashboard-widgets .meta-box-sortables {
	margin: 0 8px;
	min-height: 100px;
}

/* @todo: this was originally in this section, but likely belongs elsewhere */
#the-comment-list td.comment p.comment-author {
	margin-top: 0;
	margin-right: 0;
}

#the-comment-list p.comment-author img {
	float: right;
	margin-left: 8px;
}

#the-comment-list p.comment-author strong a {
	border: none;
}

#the-comment-list td {
	vertical-align: top;
}

#the-comment-list td.comment {
	word-wrap: break-word;
}

#the-comment-list td.comment img {
	max-width: 100%;
}

/* Welcome Panel */
.welcome-panel {
	position: relative;
	overflow: auto;
	margin: 16px 0;
	padding: 23px 10px 0;
	border: 1px solid #e5e5e5;
	-webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.04);
	box-shadow: 0 1px 1px rgba(0,0,0,0.04);
	background: #fff;
	font-size: 13px;
	line-height: 2.1em;
}

.welcome-panel h3 {
	margin: 0;
	font-size: 21px;
	font-weight: normal;
	line-height: 1.2;
}

.welcome-panel h4 {
	margin: 1.33em 0 0;
	font-size: 16px;
}

.welcome-panel li {
	font-size: 14px;
}

.welcome-panel p {
	color: #777;
}

.welcome-panel a {
	text-decoration: none;
}

.welcome-panel .about-description {
	font-size: 16px;
	margin: 0;
}

.welcome-panel .welcome-panel-close {
	position: absolute;
	top: 5px;
	left: 10px;
	padding: 20px 3px 0 15px;
	font-size: 13px;
	text-decoration: none;
	line-height: 1;
}

#welcome-panel.welcome-panel .welcome-panel-close:before {
	position: absolute;
	right: -18px;
	margin-top: -2px;
	-webkit-transition: all .1s ease-in-out;
	transition: all .1s ease-in-out;
}

.wp-core-ui .welcome-panel .button.button-hero {
	margin: 15px 0 3px 13px;
	padding: 12px 36px;
	height: auto;
	line-height: 1.4285714;
	white-space: normal;
}

.welcome-panel-content {
	margin-right: 13px;
	max-width: 1500px;
}

.welcome-panel .welcome-panel-column-container {
	clear: both;
	overflow: hidden;
	position: relative;
}

.welcome-panel .welcome-panel-column {
	width: 32%;
	min-width: 200px;
	float: right;
}

.ie8 .welcome-panel .welcome-panel-column {
	min-width: 230px;
}

.welcome-panel .welcome-panel-column:first-child {
	width: 36%;
}

.welcome-panel-column p.hide-if-no-customize {
	margin-top: 10px;
}

.welcome-panel-column p {
	margin-top: 7px;
	color: #464646;
}

.welcome-panel .welcome-icon {
	display: block;
	padding: 0 0 8px;
	background: transparent !important;
}

.welcome-panel .welcome-icon:before {
	color: #82878c;
	font: normal 20px/1 'dashicons';
	speak: none;
	display: inline-block;
	padding: 0 0 0 10px;
	top: -1px;
	position: relative;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	text-decoration: none !important;
	vertical-align: top;
}

.welcome-panel .welcome-write-blog:before,
.welcome-panel .welcome-edit-page:before {
	content:'\f119';
	top: -3px;
}

.welcome-panel .welcome-add-page:before {
	content:'\f132';
}

.welcome-panel .welcome-view-site:before {
	content:'\f115';
	top: -2px;
}

.welcome-panel .welcome-widgets-menus:before {
	content:'\f116';
	top: -2px;
}

.welcome-panel .welcome-comments:before {
	content:'\f117';
	top: -1px;
}

.welcome-panel .welcome-learn-more:before {
	content:'\f118';
	top: -1px;
}

.welcome-panel .welcome-widgets-menus {
	line-height: 16px;
}

.welcome-panel .welcome-panel-column ul {
	margin: 0.8em 0 1em 1em;
}

.welcome-panel .welcome-panel-column li {
	line-height: 16px;
	list-style-type: none;
}

/* Dashboard WordPress news */

#dashboard_primary .inside {
	margin: 0;
	padding: 0;
}

#dashboard_primary .widget-loading,
#dashboard_primary .dashboard-widget-control-form {
	padding: 12px 12px 0;
}

body #dashboard-widgets .postbox form .submit {
	margin: 0;
}

.dashboard-widget-control-form {
	overflow: hidden;
}

.dashboard-widget-control-form p {
	margin-top: 0;
}

.rssSummary {
	color: #777;
	margin-top: 4px;
}

#dashboard_primary .rss-widget {
	border-bottom: 1px solid #eee;
	font-size: 13px;
	padding: 8px 12px 10px;
}

#dashboard_primary .rss-widget:last-child {
	border-bottom: none;
	padding-bottom: 8px;
}

#dashboard_primary .rss-widget a {
	font-weight: normal;
}

#dashboard_primary .rss-widget span,
#dashboard_primary .rss-widget span.rss-date {
	color: #777;
}

#dashboard_primary .rss-widget span.rss-date {
	margin-right: 12px;
}

#dashboard_primary .rss-widget ul li {
	margin-bottom: 8px;
}

/* Dashboard right now */

#dashboard_right_now ul {
	margin: 0;
	overflow: hidden;
}

#dashboard_right_now li {
	width: 50%;
	float: right;
	margin-bottom: 10px;
}

#dashboard_right_now .inside {
	overflow: hidden;
	padding: 0;
}

#dashboard_right_now .main {
	overflow: hidden;
	padding: 0 12px 11px;
}

#dashboard_right_now .main p {
	margin: 0;
}

#dashboard_right_now #wp-version-message .button {
	float: left;
	position: relative;
	top: -5px;
	margin-right: 5px;
}

.mu-storage {
	overflow: hidden;
}

#dashboard-widgets h4.mu-storage {
	margin-bottom: 10px;
}

/* Dashboard right now - Colors */

#dashboard_right_now li a:before,
#dashboard_right_now li span:before {
	color: #82878c;
}

#dashboard_right_now .sub {
	color: #777;
	background: #f5f5f5;
	border-top: 1px solid #eee;
	padding: 10px 12px 6px 12px;
}

#dashboard_right_now .sub h4 {
	color: #555;
}

#dashboard_right_now .sub p {
	margin: 0 0 1em;
}

#dashboard_right_now .warning a:before,
#dashboard_right_now .warning span:before {
	color: #d54e21;
}

/* Dashboard right now - Icons */
#dashboard_right_now li a:before,
#dashboard_right_now li span:before {
	content: '\f159';
	font: normal 20px/1 'dashicons';
	speak: none;
	display: block;
	float: right;
	margin: 0 0 0 5px;
	padding: 0;
	text-indent: 0;
	text-align: center;
	position: relative;
	-webkit-font-smoothing: antialiased;
	text-decoration: none !important;
}

#dashboard_right_now .page-count a:before,
#dashboard_right_now .page-count span:before {
	content: '\f105';
}

#dashboard_right_now .post-count a:before,
#dashboard_right_now .post-count span:before {
	content: '\f109';
}

#dashboard_right_now .comment-count a:before {
	content: '\f101';
}

#dashboard_right_now .comment-mod-count a:before {
	content: '\f125';
}

#dashboard_right_now .storage-count a:before {
	content: '\f104';
}

#dashboard_right_now .storage-count.warning a:before {
	content: '\f153';
}

/* Dashboard Quick Draft */

#dashboard_quick_press .inside {
	margin: 0;
	padding: 0;
}

#dashboard_quick_press div.updated {
	margin-bottom: 10px;
	border: 1px solid #eee;
	border-width: 1px 0 1px 1px;
}

#dashboard_quick_press form {
	overflow: hidden;
	margin: 12px;
}

#dashboard_quick_press .drafts,
#dashboard_quick_press .easy-blogging {
	padding: 10px 0 0;
}

/* Dashboard Quick Draft - Form styling */

input#save-post {
	float: right;
}

form.initial-form.quickpress-open label.prompt {
	font-style: normal;
}

form.initial-form.quickpress-open input#title {
	height: auto;
}

#dashboard_quick_press input,
#dashboard_quick_press textarea {
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	margin: 0;
}

#dashboard_quick_press textarea {
	resize: vertical;
}

#dashboard-widgets .postbox form .submit {
	margin: -39px 0;
	float: left;
}

#description-wrap {
	margin-top: 12px;
}

#title-wrap #title-prompt-text,
.textarea-wrap #content-prompt-text {
	color: #777;
}

#title-wrap #title-prompt-text {
	font-size: 1.1em;
	padding: 7px 8px;
}

.input-text-wrap,
.textarea-wrap {
	position: relative;
}

.input-text-wrap .prompt,
.textarea-wrap .prompt {
	position: absolute;
}

.textarea-wrap #content-prompt-text {
	font-size: 1.1em;
	padding: 7px 8px;
}

.textarea-wrap textarea#content {
	margin: 0 0 8px;
	padding: 6px 7px;
}

#quick-press textarea#content {
	min-height: 90px;
	max-height: 1300px;
	resize: none;
}

/* Dashboard Quick Draft - Drafts list */

.js #dashboard_quick_press .drafts {
	border-top: 1px solid #eee;
}

#dashboard_quick_press .drafts abbr {
	border: none;
}

#dashboard_quick_press .drafts h4 {
	margin: 0 12px 8px;
	font-weight: normal;
}

#dashboard_quick_press .drafts .view-all {
	float: left;
	margin: 0 0 0 12px;
}

#dashboard_primary a.rsswidget {
	font-weight: normal;
}

#dashboard_quick_press .drafts ul {
	margin: 0 12px;
}

#dashboard_quick_press .drafts li {
	margin-bottom: 1em;
}
#dashboard_quick_press .drafts li time {
	color: #777;
}

#dashboard_quick_press .drafts p {
	margin: 0;
	word-wrap: break-word;
}

#dashboard_quick_press .draft-title {
	overflow: hidden;
}

#dashboard_quick_press .draft-title a,
#dashboard_quick_press .draft-title time {
	float: right;
	margin: 0 0 0 5px;
}

/* Dashboard activity widget */

#dashboard-widgets #dashboard_activity h4 {
	margin: 0 12px 8px 0;
	font-weight: normal;
}

#dashboard-widgets #dashboard_activity h4.comment-meta {
	margin: 0;
}

#dashboard_activity h4.comment-meta {
	margin-bottom: 4px;
}

#dashboard_activity ul {
	padding: 0 12px;
}

#dashboard_activity .comment-meta span.approve:before {
	content: '\f227';
	font: 20px/.5 "dashicons";
	margin-right: 12px;
	vertical-align: middle;
	position: relative;
	top: -1px;
	margin-left: 2px;
}

#dashboard_activity .inside {
	padding: 0;
	margin: 0;
}

#dashboard_activity .no-activity {
	overflow: hidden;
	padding: 0 12px 12px;
	text-align: center;
}

#dashboard_activity .no-activity p {
	color: #999;
	font-size: 16px;
}

#dashboard_activity .no-activity .smiley {
	margin-top: 0;
}

#dashboard_activity .no-activity .smiley:before {
	content: '\f328';
	font: normal 120px/1 'dashicons';
	speak: none;
	display: block;
	margin: 0 0 0 5px;
	padding: 0;
	text-indent: 0;
	text-align: center;
	position: relative;
	-webkit-font-smoothing: antialiased;
	text-decoration: none !important;
}

#dashboard_activity .subsubsub {
	float: none;
	border-top: 1px solid #eeeeee;
	margin-top: 0;
	padding: 8px 12px 4px;
}

#future-posts ul,
#published-posts ul {
	clear: both;
	margin-bottom: 0;
}

#future-posts li,
#published-posts li {
	overflow: hidden;
	margin-bottom: 8px;
}

#future-posts ul span,
#published-posts ul span {
	color: #777;
	float: right;
	margin-left: 8px;
	min-width: 150px;
}

.activity-block {
	border-bottom: 1px solid #eee;
	overflow: hidden;
	padding: 8px 0 4px;
}

.activity-block:last-child {
	border-bottom: none;
}

.activity-block .subsubsub li {
	color: #ddd;
}

/* Dashboard activity widget - Comments */
/* @todo: needs serious de-duplication */

#activity-widget #the-comment-list tr.undo,
#activity-widget #the-comment-list div.undo {
	background: none;
	padding: 6px 0;
	margin-right: 12px;
}

#activity-widget #the-comment-list .comment-item {
	background: #fafafa;
	padding: 12px;
	position: relative;
}

#activity-widget #the-comment-list .avatar {
	position: absolute;
	top: 13px;
}

#activity-widget #the-comment-list .dashboard-comment-wrap {
	padding-right: 63px;
}

#activity-widget #the-comment-list .dashboard-comment-wrap blockquote {
	margin: 1em 0;
}

#activity-widget #the-comment-list .comment-item h4 {
	font-size: 13px;
	color: #999;
}

#activity-widget #the-comment-list .comment-item p.row-actions {
	margin: 4px 0 0 0;
}

#activity-widget #the-comment-list .comment-item:first-child {
	border-top: 1px solid #eeeeee;
}

#activity-widget #the-comment-list .unapproved {
	background-color: #fef7f1;
}

#activity-widget #the-comment-list .unapproved:before {
	content: "";
	display: block;
	position: absolute;
	right: 0;
	top: 0;
	bottom: 0;
	background: #d54e21;
	width: 4px;
}

#activity-widget #the-comment-list .spam-undo-inside .avatar,
#activity-widget #the-comment-list .trash-undo-inside .avatar {
	position: relative;
	top: 0;
}

/* Browse happy box */

#dashboard-widgets #dashboard_browser_nag.postbox .inside {
	margin: 10px;
}

.edit-box {
	display: none;
}

h3:hover .edit-box {
	display: inline;
}

#dashboard-widgets form .input-text-wrap input {
	width: 100%;
}

#dashboard-widgets form .textarea-wrap textarea {
	width: 100%;
}

#dashboard-widgets .postbox form .submit {
	float: none;
	margin: .5em 0 0;
	padding: 0;
	border: none;
}

#dashboard-widgets-wrap #dashboard-widgets .postbox form .submit #publish {
	min-width: 0;
}

#dashboard-widgets a {
	text-decoration: none;
}

#dashboard-widgets h3 a {
	text-decoration: underline;
}

#dashboard-widgets h3 .postbox-title-action {
	position: absolute;
	left: 10px;
	padding: 0;
	top: 5px;
}

.js #dashboard-widgets h3 .postbox-title-action {
	left: 33px;
}

#dashboard-widgets h4 {
	color: #23282d;
	font-weight: normal;
	font-size: 14px;
	margin: 0 0 .2em;
	padding: 0;
}

#dashboard_plugins h5 {
	font-size: 14px;
}

/* Recent Comments */

#latest-comments #the-comment-list {
	position: relative;
}

#activity-widget #the-comment-list .comment,
#activity-widget #the-comment-list .pingback {
	-webkit-box-shadow: inset 0 1px 0 rgba(0, 0, 0, 0.06);
	box-shadow: inset 0 1px 0 rgba(0, 0, 0, 0.06);
}

#activity-widget .comments #the-comment-list .alt {
	background-color: transparent;
}

#activity-widget #latest-comments #the-comment-list .comment-item {
	padding: 1em 12px;
}

#latest-comments #the-comment-list .pingback {
	padding-right: 12px !important;
}

#latest-comments #the-comment-list .comment-item:first-child {
	border-top: none;
}

#latest-comments #the-comment-list .comment-item h4 {
	line-height: 1.5em;
	margin-top: 0;
	color: #666;
}

#latest-comments #the-comment-list .comment-item h4 cite {
	font-style: normal;
	font-weight: normal;
}

#latest-comments #the-comment-list .comment-item blockquote,
#latest-comments #the-comment-list .comment-item blockquote p {
	margin: 0;
	padding: 0;
	display: inline;
}

#latest-comments #the-comment-list .comment-item p.row-actions {
	margin: 3px 0 0;
	padding: 0;
	font-size: 13px;
}

/* QuickDraft */

#title-wrap label,
#description-wrap label {
	cursor: text;
}

#title-wrap #title {
	padding: 2px 6px;
	font-size: 1.3em;
	outline: none;
}

#title-wrap #title-prompt-text {
	font-size: 1.1em;
	padding: 5px 8px;
}

/* Feeds */
.rss-widget ul {
	margin: 0;
	padding: 0;
	list-style: none;
}

a.rsswidget {
	font-size: 14px;
	font-weight: 600;
	line-height: 1.7em;
}

.rss-widget ul li {
	line-height: 1.5em;
	margin-bottom: 12px;
}

.rss-widget span.rss-date {
	color: #999;
	font-size: 13px;
	margin-right: 3px;
}

.rss-widget cite {
	display: block;
	text-align: left;
	margin: 0 0 1em;
	padding: 0;
}

.rss-widget cite:before {
	content: '\2014';
}

.dashboard-comment-wrap {
	overflow: hidden;
	word-wrap: break-word;
}

/* Browser Nag */
#dashboard_browser_nag a.update-browser-link {
	font-size: 1.2em;
	font-weight: 600;
}

#dashboard_browser_nag a {
	text-decoration: underline;
}

#dashboard_browser_nag p.browser-update-nag.has-browser-icon {
	padding-left: 125px;
}

#dashboard_browser_nag .browser-icon {
	margin-top: -35px;
}

#dashboard_browser_nag.postbox.browser-insecure {
	background-color: #ac1b1b;
	border-color: #ac1b1b;
}

#dashboard_browser_nag.postbox {
	background-color: #e29808;
	background-image: none;
	border-color: #edc048;
	color: #fff;
	-webkit-box-shadow: none;
	box-shadow: none;
}

#dashboard_browser_nag.postbox.browser-insecure h3 {
	border-bottom-color: #cd5a5a;
	color: #fff;
}

#dashboard_browser_nag.postbox h3 {
	border-bottom-color: #f6e2ac;
	background: transparent none;
	color: #fff;
	-webkit-box-shadow: none;
	box-shadow: none;
}

#dashboard_browser_nag a {
	color: #fff;
}

/* Make the browser nags easier to read with Open Sans */

#dashboard_browser_nag h3.hndle {
	border: none;
	font-weight: 600;
	font-size: 20px;
	padding-top: 10px;
}

.postbox#dashboard_browser_nag p a.dismiss {
	font-size: 14px;
}

.postbox#dashboard_browser_nag p,
.postbox#dashboard_browser_nag a,
.postbox#dashboard_browser_nag p.browser-update-nag {
	font-size: 16px;
}

/* =Media Queries
-------------------------------------------------------------- */

/* one column on the dash */
@media only screen and (max-width: 799px) {
	#wpbody-content #dashboard-widgets .postbox-container {
		width: 100%;
	}
}

/* two columns on the dash, but keep the setting if one is selected */
@media only screen and (min-width: 800px) and (max-width: 1499px) {
	#wpbody-content #dashboard-widgets .postbox-container {
		width: 49.5%;
	}

	#wpbody-content #dashboard-widgets #postbox-container-2,
	#wpbody-content #dashboard-widgets #postbox-container-3,
	#wpbody-content #dashboard-widgets #postbox-container-4 {
		float: left;
		width: 50.5%;
	}

	#dashboard-widgets #postbox-container-3 .empty-container,
	#dashboard-widgets #postbox-container-4 .empty-container {
		border: 0 none;
		height: 0;
		min-height: 0;
	}

	#wpbody #wpbody-content #dashboard-widgets.columns-1 .postbox-container {
		width: 100%;
	}

	#wpbody #wpbody-content .metabox-holder.columns-1 .postbox-container .empty-container {
		border: 0 none;
		height: 0;
		min-height: 0;
	}

	/* show the radio buttons for column prefs only for one or two columns */
	.index-php .screen-layout,
	.index-php .columns-prefs {
		display: block;
	}

	.columns-prefs .columns-prefs-3,
	.columns-prefs .columns-prefs-4 {
		display: none;
	}
}

/* three columns on the dash */
@media only screen and (min-width: 1500px) and (max-width: 1800px) {
	#wpbody-content #dashboard-widgets .postbox-container {
		width: 33.5%;
	}

	#wpbody-content #dashboard-widgets #postbox-container-1 {
		width: 33%;
	}

	#wpbody-content #dashboard-widgets #postbox-container-3,
	#wpbody-content #dashboard-widgets #postbox-container-4 {
		float: left;
	}

	#dashboard-widgets #postbox-container-4 .empty-container {
		border: 0 none;
		height: 0;
		min-height: 0;
	}
}

@media screen and (max-width: 870px) {
	.welcome-panel .welcome-panel-column,
	.welcome-panel .welcome-panel-column:first-child {
		display: block;
		float: none;
		width: 100%;
	}

	.welcome-panel .welcome-panel-column li {
		display: inline-block;
		margin-left: 13px;
	}

	.welcome-panel .welcome-panel-column ul {
		margin: 0.4em 0 0;
	}

}

@media screen and ( max-width: 782px ) {
	#dashboard_recent_comments #the-comment-list .comment-item .avatar {
		height: 30px;
		width: 30px;
		margin: 4px 0 5px 10px;
	}
}

/* Smartphone */
@media screen and (max-width: 600px) {
	/* Keep the close icon from overlapping the Welcome text. */
	.welcome-panel .welcome-panel-close {
		overflow: hidden;
		text-indent: 100%;
		white-space: nowrap;
		width: 20px;
		height: 20px;
		left: 0;
		padding: 5px;
	}

	/* Make the close icon larger for tappability. */
	#welcome-panel.welcome-panel .welcome-panel-close:before {
		font-size: 20px;
		margin: 0;
	}
}
