/* This file was automatically generated on Aug 26 2014 19:31:54 */

#menu-posts-feedback .wp-menu-image img {
	display: none;
}

#adminmenu .menu-icon-feedback div.wp-menu-image {
	background: none !important;
}

#adminmenu .menu-icon-feedback div.wp-menu-image:before {
	content: '\f175';
	margin-right: -1px;
}

.jetpack-contact-form-icon:before {
	content: '\f175';
	color: #888;
	vertical-align: text-bottom;
	font: normal 18px/1 'dashicons';
	speak: none;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
