<?php
/**
 * South African states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['ZA'] = array(
	'EC'  => __( 'Eastern Cape', 'woocommerce' ),
	'FS'  => __( 'Free State', 'woocommerce' ),
	'GP'  => __( 'Gauteng', 'woocommerce' ),
	'KZN' => __( 'KwaZulu-Natal', 'woocommerce' ),
	'LP'  => __( 'Limpopo', 'woocommerce' ),
	'MP'  => __( 'Mpumalanga', 'woocommerce' ),
	'NC'  => __( 'Northern Cape', 'woocommerce' ),
	'NW'  => __( 'North West', 'woocommerce' ),
	'WC'  => __( 'Western Cape', 'woocommerce' )
);
