<?php

/**
 * Module Name: Carousel
 * Module Description: Transform standard image galleries into full-screen slideshows.
 * Jumpstart Description: brings your photos and images to life as full-size, easily navigable galleries.
 * Sort Order: 22
 * Recommendation Order: 12
 * First Introduced: 1.5
 * Requires Connection: No
 * Auto Activate: No
 * Module Tags: Photos and Videos
 * Feature: Jumpstart
 */

include dirname( __FILE__ ) . '/carousel/jetpack-carousel.php';
