/*
Theme Name: Twenty Fifteen
Description: IE7 specific style.
*/

.screen-reader-text {
	clip: rect(1px 1px 1px 1px);
}

.secondary-toggle {
	color: #333;
	font-size: 16px;
	line-height: 60px;
	width: auto;
}

.pagination .prev,
.pagination .next {
	font-size: 16px;
	font-weight: 700;
	line-height: 64px;
	padding: 0 19px;
	width: auto;
}

.image-navigation,
.comment-navigation {
	width: 662px;
}

.post-navigation {
	text-align: left;
}

.site-main {
	text-align: center;
}

.hentry {
	margin-bottom: 7.6923%;
	text-align: left;
	width: 808px;
}

.page-header {
	margin-bottom: 7.6923%;
	text-align: left;
}

.comments-area {
	text-align: left;
}

.comment-list,
.comment-navigation {
	margin-bottom: 1.6471em;
}

.gallery-columns-2 .gallery-item {
	max-width: 48%;
}

.gallery-columns-3 .gallery-item {
	max-width: 31%;
}

.gallery-columns-4 .gallery-item {
	max-width: 22%;
}

.gallery-columns-5 .gallery-item {
	max-width: 17%;
}

.gallery-columns-6 .gallery-item {
	max-width: 13.5%;
}

.gallery-columns-7 .gallery-item {
	max-width: 11%;
}

.gallery-columns-8 .gallery-item {
	max-width: 9.5%;
}

.gallery-columns-9 .gallery-item {
	max-width: 8%;
}
