<?php
/**
 * Hong Kong states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['HK'] = array(
	'HONG KONG'       => __( 'Hong Kong Island', 'woocommerce' ),
	'KOWLOON'         => __( 'Kowloon', 'woocommerce' ),
	'NEW TERRITORIES' => __( 'New Territories', 'woocommerce' )
);
