<?php
/**
 * Mexico States
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.2.3
 */
global $states;

$states['MX'] = array(
	'Distrito Federal' 	=> __( 'Distrito Federal', 'woocommerce' ),
	'Jalisco' 		=> __( 'Jalisco', 'woocommerce' ),
	'Nuevo Leon' 		=> __( 'Nuevo León', 'woocommerce' ),
	'Aguascalientes' 	=> __( 'Aguascalientes', 'woocommerce' ),
	'Baja California' 	=> __( 'Baja California', 'woocommerce' ),
	'Baja California Sur' 	=> __( 'Baja California Sur', 'woocommerce' ),
	'Campeche' 		=> __( 'Campeche', 'woocommerce' ),
	'Chiapas' 		=> __( 'Chiapas', 'woocommerce' ),
	'Chihuahua' 		=> __( 'Chihuahua', 'woocommerce' ),
	'Coahuila' 		=> __( 'Coahuila', 'woocommerce' ),
	'Colima' 		=> __( 'Colima', 'woocommerce' ),
	'Durango' 		=> __( 'Durango', 'woocommerce' ),
	'Guanajuato' 		=> __( 'Guanajuato', 'woocommerce' ),
	'Guerrero' 		=> __( 'Guerrero', 'woocommerce' ),
	'Hidalgo' 		=> __( 'Hidalgo', 'woocommerce' ),
	'Estado de Mexico' 	=> __( 'Edo. de México', 'woocommerce' ),
	'Michoacan' 		=> __( 'Michoacán', 'woocommerce' ),
	'Morelos' 		=> __( 'Morelos', 'woocommerce' ),
	'Nayarit' 		=> __( 'Nayarit', 'woocommerce' ),
	'Oaxaca' 		=> __( 'Oaxaca', 'woocommerce' ),
	'Puebla' 		=> __( 'Puebla', 'woocommerce' ),
	'Queretaro' 		=> __( 'Querétaro', 'woocommerce' ),
	'Quintana Roo' 		=> __( 'Quintana Roo', 'woocommerce' ),
	'San Luis Potosi' 	=> __( 'San Luis Potosí', 'woocommerce' ),
	'Sinaloa' 		=> __( 'Sinaloa', 'woocommerce' ),
	'Sonora' 		=> __( 'Sonora', 'woocommerce' ),
	'Tabasco' 		=> __( 'Tabasco', 'woocommerce' ),
	'Tamaulipas' 		=> __( 'Tamaulipas', 'woocommerce' ),
	'Tlaxcala' 		=> __( 'Tlaxcala', 'woocommerce' ),
	'Veracruz' 		=> __( 'Veracruz', 'woocommerce' ),
	'Yucatan' 		=> __( 'Yucatán', 'woocommerce' ),
	'Zacatecas' 		=> __( 'Zacatecas', 'woocommerce' )
);
