.wp-customizer  .expanded .widget-conditional .widget-conditional-inner {
	width: 98%;
	-webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */
	-moz-box-sizing: border-box;    /* Firefox, other Gecko */
	box-sizing: border-box;
}

.wp-customizer  .expanded .widget-conditional .form{
	overflow: scroll;
	margin-bottom: 20px;
}
.widget-liquid-right .widget.expanded {
	overflow: visible;
}
.widget-conditional-hide {
	display: none;
}
.widget-conditional .widget-conditional-inner {
	background: #F9F9F9;
	border: 1px solid #DFDFDF;
	padding: 12px 10px 0;

}
.widget-conditional {
	margin-bottom: 12px;
}
.widget-conditional .conditions{
	margin-bottom: 12px;
}
.widget-conditional .condition,
.widget-conditional .condition-top {
	clear:both;
}
.widget-conditional .condition {
	padding-top: 12px;
}
.widget-conditional .condition select {
	width: 120px;
}
.widget-conditional .condition-top select {
	width: auto;
}
.widget-conditional .condition-control {
	padding-top: 4px;
	clear: both;
	margin-top: -20px;
}
.widget-conditional .selection {
	margin-left: 70px;
}
.widget-conditional .condition .actions {
	margin-top: -28px;
}

.widget-conditional .condition-control a {
	text-decoration: none;
}
.widget-conditional .condition:last-child .condition-conjunction {
	display: none;
}

.wp-core-ui .button.display-options {
	margin-left: 5px;
}
.wp-core-ui .button.display-options:hover {
	text-decoration: none;
}

.wp-customizer .widget-conditional select {
	min-width: 0;
	max-width: none;
	height: auto;
}
