/*!
* Do not modify this file directly.  It is compiled Sass code.
* @see: jetpack/_inc/jetpack.scss
*/
/*
 * Button mixin- creates 3d-ish button effect with correct
 * highlights/shadows, based on a base color.
 */
#jetpack_summary_widget * {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
#jetpack_summary_widget .inside {
  margin: 0;
  padding: 0;
  font-family: "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
}
#jetpack_summary_widget .stats,
#jetpack_summary_widget .widgets,
#jetpack_summary_widget .wpcom-connect {
  padding: .75em;
}
#jetpack_summary_widget .wpcom-connect {
  background: #fafafa;
  text-align: center;
}
#jetpack_summary_widget .wpcom-connect .jp-emblem {
  padding: 5px 0 0 0;
}
#jetpack_summary_widget .wpcom-connect svg {
  width: 40px;
  height: 40px;
}
#jetpack_summary_widget .wpcom-connect svg path {
  fill: #81a844;
}
#jetpack_summary_widget .wpcom-connect .jp-emblem,
#jetpack_summary_widget .wpcom-connect h3,
#jetpack_summary_widget .wpcom-connect p {
  width: 100%;
}
#jetpack_summary_widget .wpcom-connect h3 {
  font-size: 1.25em;
  font-weight: 400;
}
#jetpack_summary_widget .wpcom-connect p {
  color: #777;
  margin-top: 0;
  padding: 0 15px;
}
#jetpack_summary_widget .wpcom-connect .actions {
  text-align: center;
  padding: 15px 0 10px 0;
}
#jetpack_summary_widget .wpcom-connect .actions small {
  display: block;
}
#jetpack_summary_widget .wpcom-connect .actions small a {
  color: #999;
}
#jetpack_summary_widget .button-jetpack {
  background: #81a844;
  border-color: #658435;
  color: white;
  box-shadow: inset 0 1px 0 #a5c672, 0 1px 0 rgba(0, 0, 0, 0.15);
}
#jetpack_summary_widget .button-jetpack:hover, #jetpack_summary_widget .button-jetpack:focus {
  background: #73963d;
  border-color: #57722e;
  color: white;
  box-shadow: inset 0 1px 0 #9abf60;
}
#jetpack_summary_widget .button-jetpack:focus {
  box-shadow: inset 0 1px 0 #9abf60, 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, 0.8);
}
#jetpack_summary_widget .button-jetpack:active {
  background: #658435;
  border-color: #57722e;
  color: white;
  box-shadow: inset 0 2px 5px -3px rgba(0, 0, 0, 0.5), 0 0 0 1px #5b9dd9, 0 0 2px 1px rgba(30, 140, 190, 0.8);
}
#jetpack_summary_widget .button-jetpack[disabled], #jetpack_summary_widget .button-jetpack:disabled, #jetpack_summary_widget .button-jetpack.button-primary-disabled, #jetpack_summary_widget .button-jetpack.disabled {
  color: #cdd1c7 !important;
  background: #6b8b38 !important;
  border-color: #57722e !important;
  text-shadow: none !important;
}
#jetpack_summary_widget footer {
  background: #fafafa;
  padding: .75em;
  overflow: hidden;
  border-top: 1px solid #ccc;
}
#jetpack_summary_widget footer .protect,
#jetpack_summary_widget footer .akismet {
  width: 50%;
  float: left;
  text-align: left;
}
#jetpack_summary_widget footer h3 {
  font-size: 1.5em;
  font-weight: normal;
  margin: 0;
  padding: 0;
}
#jetpack_summary_widget footer p {
  margin: 0;
  padding: 0;
}
#jetpack_summary_widget footer section {
  margin: 0;
  padding: 0;
  text-align: center;
}

/*# sourceMappingURL=dashboard-widget.css.map */