<?php
/**
 * Australian states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['AU'] = array(
	'ACT' => __( 'Australian Capital Territory', 'woocommerce' ),
	'NSW' => __( 'New South Wales', 'woocommerce' ),
	'NT'  => __( 'Northern Territory', 'woocommerce' ),
	'QLD' => __( 'Queensland', 'woocommerce' ),
	'SA'  => __( 'South Australia', 'woocommerce' ),
	'TAS' => __( 'Tasmania', 'woocommerce' ),
	'VIC' => __( 'Victoria', 'woocommerce' ),
	'WA'  => __( 'Western Australia', 'woocommerce' )
);
