/*------------------------------------------------------------------------------
  22.0 - About Pages

   1.0 Global: About, Credits, Freedoms
    1.1 Typography
    1.2 Structure
    1.3 Point Releases
   2.0 About Page
    2.1 Typography
    2.2 Structure
   3.0 Credits & Freedoms Pages
------------------------------------------------------------------------------*/

/*------------------------------------------------------------------------------
  1.0 - Global: About, Credits, Freedoms
------------------------------------------------------------------------------*/

.about-wrap {
	position: relative;
	margin: 25px 20px 0 40px;
	max-width: 1050px; /* readability */
	font-size: 15px;
}

.about-wrap div.updated,
.about-wrap div.error {
	display: none !important;
}

.about-wrap hr {
	border: 0;
	height: 0;
	margin: 0;
	border-top: 1px solid rgba(0, 0, 0, 0.1);
}

.about-wrap img {
	margin: 0;
	max-width: 100%;
	height: auto;
	vertical-align: middle;
}

/* WordPress Version Badge */

.wp-badge {
	background: #0073aa url(../images/w-logo-white.png?ver=20131202) no-repeat;
	background-position: center 24px;
	-webkit-background-size: 85px 85px;
	background-size: 85px 85px;
	color: #78c8e6;
	font-size: 14px;
	text-align: center;
	font-weight: 600;
	margin: 5px 0 0;
	padding-top: 120px;
	height: 40px;
	display: inline-block;
	width: 150px;
	text-rendering: optimizeLegibility;
	-webkit-box-shadow: 0 1px 3px rgba(0,0,0,0.2);
	box-shadow: 0 1px 3px rgba(0,0,0,0.2);
}

.svg .wp-badge {
	background-image: url(../images/wordpress-logo-white.svg?ver=20131110);
}

.about-wrap .wp-badge {
	position: absolute;
	top: 0;
	left: 0;
}

/* Tabs */

.about-wrap h2.nav-tab-wrapper {
	padding-right: 6px;
}

.about-wrap h2 .nav-tab {
	padding: 4px 15px 6px;
	margin: 0 0 -1px 3px;
	font-size: 18px;
	vertical-align: top;
	border-width: 1px;
	white-space: nowrap;
}

/* 1.1 - Typography */

.about-wrap p {
	line-height: 1.6em;
	font-size: 14px;
}

.about-wrap h1 {
	margin: 0.2em 0 0 200px;
	color: #32373c;
	line-height: 1.2em;
	font-size: 2.8em;
	font-weight: 400;
}

.about-wrap h3 {
	margin: 1.25em 0 .6em;
	font-size: 1.25em;
	line-height: 1.5em;
}

.about-wrap h4 {
	color: #23282d;
}

.about-wrap code,
.about-wrap ol li p {
	font-size: 14px;
}

.about-wrap .about-description,
.about-wrap .about-text {
	margin-top: 1.4em;
	font-weight: normal;
	line-height: 1.6em;
	font-size: 19px;
}

.about-wrap .about-text {
	margin: 1em 0 1em 200px;
	min-height: 60px;
	color: #777;
}

/* 1.2 - Structure */

.about-wrap .two-col > div {
	position: relative;
	width: 47.6%;
	margin-left: 4.799999999%;
	float: right;
}

.about-wrap .three-col > div {
	position: relative;
	width: 29.95%;
	margin-left: 4.999999999%;
	float: right;
}

.about-wrap [class$=col] .last-feature {
	margin-left: 0;
}

/* 1.3 - Point Releases */

.about-wrap .point-releases {
	margin-top: 5px;
	border-bottom: 1px solid #dfdfdf;
}

.about-wrap .changelog.point-releases h3 {
	padding-top: 35px;
}

.about-wrap .changelog.point-releases h3:first-child {
	padding-top: 7px;
}

/*------------------------------------------------------------------------------
  2.0 - About Page
------------------------------------------------------------------------------*/

/* 2.1 - Typography */

.about-wrap .headline-feature h2 {
	margin: 50px 0 30px;
	font-size: 2.2em;
	font-weight: 300;
	line-height: 1.3;
	text-align: right;
}

.about-wrap .headline-feature h3 {
	margin-top: 30px;
	text-align: center;
}

.about-wrap .feature-list h2 {
	margin: 30px 0 15px;
	text-align: center;
}

.about-wrap .feature-section h4 {
	margin: 1.4em 0 0.6em 0;
	font-size: 1em;
}

.about-wrap .feature-section p {
	margin-top: 0.6em;
}

/* 2.2 - Structure */

.about-wrap .feature-video {
	position: relative;
	margin: 40px 0;
	padding-bottom: 56.25%; /* video is 1280 x 720 */
	width: 100%;
	height: 0;
	text-align: center;
}

.about-wrap .feature-video embed {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.about-wrap .featured-image {
	text-align: center;
}

.about-wrap .feature-section {
	overflow: hidden;
	padding: 0 0 40px;
	border-bottom: 1px solid rgba(0, 0, 0, 0.1);
}

.about-wrap .headline-feature .feature-section {
	margin: 0 auto;
	max-width: 95%;
}

.about-wrap .feature-section .col:nth-of-type(odd) {
	float: right;
	margin: 40px 0 0 5%;
	width: 48%;
}

.about-wrap .feature-section .col:nth-of-type(even) {
	float: left;
	margin: 40px 0 0;
	width: 46%;
}

.about-wrap .changelog {
	margin-bottom: 40px;
}

.about-wrap .changelog.feature-section > div {
	margin-top: 40px;
}

/* Return to Dashboard Home link */

.about-wrap .return-to-dashboard {
	margin: 30px -5px 0 0;
	font-size: 14px;
	font-weight: bold;
}

.about-wrap .return-to-dashboard a {
	text-decoration: none;
	padding: 0 5px;
}

.about-wrap .feature-list.finer-points h4,
.about-wrap .feature-list.finer-points p {
	margin-right: 115px;
}

/*------------------------------------------------------------------------------
  3.0 - Credits & Freedoms Pages
------------------------------------------------------------------------------*/

/* Credits */

.about-wrap h4.wp-people-group {
	margin-top: 2.6em;
	font-size: 16px;
}

.about-wrap ul.wp-people-group {
	overflow: hidden;
	padding: 0 5px;
	margin: 0 -5px 0 -15px;
}

.about-wrap ul.compact {
	margin-bottom: 0
}

.about-wrap li.wp-person {
	display: inline-block;
	vertical-align: top;
	margin-left: 10px;
	padding-bottom: 15px;
	height: 70px;
	width: 280px;
}

.about-wrap ul.compact li.wp-person {
	height: auto;
	width: 180px;
	padding-bottom: 0;
	margin-bottom: 0;
}

.about-wrap li.wp-person img.gravatar {
	float: right;
	margin: 0 0 10px 10px;
	padding: 2px;
	width: 60px;
	height: 60px;
}

.about-wrap ul.compact li.wp-person img.gravatar {
	width: 30px;
	height: 30px;
}

.about-wrap li.wp-person a.web {
	display: block;
	margin: 6px 0 2px;
	font-size: 16px;
	font-weight: normal;
	line-height: 1.6em;
	text-decoration: none;
}

.about-wrap #wp-people-group-validators + p.wp-credits-list {
	margin-top: 0;
}

.about-wrap p.wp-credits-list a {
	white-space: nowrap;
}

/* Freedoms */

.freedoms-php .about-wrap ol {
	margin: 40px 60px;
}

.freedoms-php .about-wrap ol li {
	list-style-type: decimal;
	font-weight: bold;
}

.freedoms-php .about-wrap ol p {
	font-weight: normal;
	margin: 0.6em 0;
}

/*------------------------------------------------------------------------------
  4.0 - Media Queries
------------------------------------------------------------------------------*/

@media screen and ( max-width: 782px ) {
	.about-wrap .feature-section {
		padding: 0;
		border-bottom: none;
	}

	.about-wrap .one-col > div,
	.about-wrap .two-col > div,
	.about-wrap .three-col > div,
	.about-wrap .two-col .col:nth-of-type(n) {
		width: 100%;
		margin: 40px 0 0;
		padding: 0 0 40px;
		border-bottom: 1px solid rgba(0, 0, 0, 0.1);
	}

	.about-wrap .two-col .col h3 {
		margin-top: 0;
	}

	.about-wrap .three-col img {
		display: block;
		margin: 0 auto;
	}

	.about-wrap .feature-list div {
		margin: 0;
		padding: 0;
		border-bottom: none;
	}

	.about-wrap .headline-feature .feature-section {
		max-width: 100%;
	}

	.about-wrap .feature-list .feature-section {
		padding: 0 0 40px;
	}
}

@media only screen and (max-width: 500px) {
	.about-wrap {
		margin-left: 20px;
		margin-right: 10px;
	}

	.about-wrap h1,
	.about-wrap .about-text {
		margin-left: 0;
	}

	.about-wrap .about-text {
		margin-bottom: 0.25em;
	}

	.about-wrap .wp-badge {
		position: relative;
		margin-bottom: 1.5em;
		width: 100%;
	}

	.about-wrap h2.nav-tab-wrapper {
		padding-right: 0;
		border-bottom: 0;
	}

	.about-wrap h2 .nav-tab {
		margin-top: 10px;
		margin-left: 10px;
		border-bottom: 1px solid #ccc;
	}

	.about-wrap .three-col div,
	.about-wrap .headline-feature .feature-section div {
		width: 100% !important;
		float: none !important;
	}

	.about-wrap .dfw p {
		max-width: 90%;
	}
}

@media only screen and (max-width: 400px) {
	.about-wrap .feature-list svg {
		margin-top: 15px;
		height: 65px;
		width: 65px;
	}
	.about-wrap .feature-list.finer-points h4,
	.about-wrap .feature-list.finer-points p {
		margin-right: 80px;
	}
}
