<?php return;

/**
 * This file exists soley to store the module
 * header translation strings, that exist ordinarily
 * in comments on files in this directory.
 *
 * It is never included anywhere, and is used for parsing.
 */

// modules/after-the-deadline.php
_x( 'Spelling and Grammar', 'Module Name', 'jetpack' );
_x( 'Check your spelling, style, and grammar with the After the Deadline proofreading service.', 'Module Description', 'jetpack' );

// modules/carousel.php
_x( 'Carousel', 'Module Name', 'jetpack' );
_x( 'Transform standard image galleries into full-screen slideshows.', 'Module Description', 'jetpack' );
_x( 'brings your photos and images to life as full-size, easily navigable galleries.', 'Jumpstart Description', 'jetpack' );

// modules/comments.php
_x( 'Jetpack Comments', 'Module Name', 'jetpack' );
_x( 'Let readers comment with WordPress.com, Twitter, Facebook, or Google+ accounts.', 'Module Description', 'jetpack' );

// modules/contact-form.php
_x( 'Contact Form', 'Module Name', 'jetpack' );
_x( 'Insert a contact form anywhere on your site.', 'Module Description', 'jetpack' );
_x( 'adds a button to your post and page editors, allowing you to build simple forms to help visitors stay in touch.', 'Jumpstart Description', 'jetpack' );

// modules/custom-content-types.php
_x( 'Custom Content Types', 'Module Name', 'jetpack' );
_x( 'Organize and display different types of content on your site, separate from posts and pages.', 'Module Description', 'jetpack' );

// modules/custom-css.php
_x( 'Custom CSS', 'Module Name', 'jetpack' );
_x( 'Customize your site’s CSS without modifying your theme.', 'Module Description', 'jetpack' );

// modules/enhanced-distribution.php
_x( 'Enhanced Distribution', 'Module Name', 'jetpack' );
_x( 'Share your public posts and comments to search engines and other services.', 'Module Description', 'jetpack' );

// modules/gravatar-hovercards.php
_x( 'Gravatar Hovercards', 'Module Name', 'jetpack' );
_x( 'Enable pop-up business cards over commenters’ Gravatars.', 'Module Description', 'jetpack' );
_x( 'let commenters link their profiles to their Gravatar accounts, making it easy for your visitors to learn more about your community.', 'Jumpstart Description', 'jetpack' );

// modules/infinite-scroll.php
_x( 'Infinite Scroll', 'Module Name', 'jetpack' );
_x( 'Add support for infinite scroll to your theme.', 'Module Description', 'jetpack' );

// modules/json-api.php
_x( 'JSON API', 'Module Name', 'jetpack' );
_x( 'Allow applications to securely access your content through the cloud.', 'Module Description', 'jetpack' );

// modules/latex.php
_x( 'Beautiful Math', 'Module Name', 'jetpack' );
_x( 'Use LaTeX markup language in posts and pages for complex equations and other geekery.', 'Module Description', 'jetpack' );

// modules/likes.php
_x( 'Likes', 'Module Name', 'jetpack' );
_x( 'Give visitors an easy way to show their appreciation for your content.', 'Module Description', 'jetpack' );

// modules/manage.php
_x( 'Manage', 'Module Name', 'jetpack' );
_x( 'Manage all your sites from a centralized place, https://wordpress.com/sites.', 'Module Description', 'jetpack' );
_x( 'helps you remotely manage plugins, turn on automated updates, and more from <a href="https://wordpress.com/plugins/" target="_blank">wordpress.com</a>.', 'Jumpstart Description', 'jetpack' );

// modules/markdown.php
_x( 'Markdown', 'Module Name', 'jetpack' );
_x( 'Write posts or pages in plain-text Markdown syntax.', 'Module Description', 'jetpack' );

// modules/minileven.php
_x( 'Mobile Theme', 'Module Name', 'jetpack' );
_x( 'Optimize your site with a mobile-friendly theme for smartphones.', 'Module Description', 'jetpack' );

// modules/monitor.php
_x( 'Monitor', 'Module Name', 'jetpack' );
_x( 'Receive notifications from Jetpack if your site goes offline — and when it it returns.', 'Module Description', 'jetpack' );

// modules/notes.php
_x( 'Notifications', 'Module Name', 'jetpack' );
_x( 'Receive notification of site activity via the admin toolbar and your Mobile devices.', 'Module Description', 'jetpack' );

// modules/omnisearch.php
_x( 'Omnisearch', 'Module Name', 'jetpack' );
_x( 'Search your entire database from a single field in your Dashboard.', 'Module Description', 'jetpack' );

// modules/photon.php
_x( 'Photon', 'Module Name', 'jetpack' );
_x( 'Accelerate your site by loading images from the WordPress.com CDN.', 'Module Description', 'jetpack' );
_x( 'mirrors and serves your images from our free and fast image CDN, improving your site’s performance with no additional load on your servers.', 'Jumpstart Description', 'jetpack' );

// modules/post-by-email.php
_x( 'Post by Email', 'Module Name', 'jetpack' );
_x( 'Publish posts by email, using any device and email client.', 'Module Description', 'jetpack' );

// modules/protect.php
_x( 'Protect', 'Module Name', 'jetpack' );
_x( 'Adds brute force protection to your login page. Formerly BruteProtect.', 'Module Description', 'jetpack' );

// modules/publicize.php
_x( 'Publicize', 'Module Name', 'jetpack' );
_x( 'Share new posts on social media networks automatically.', 'Module Description', 'jetpack' );

// modules/related-posts.php
_x( 'Related Posts', 'Module Name', 'jetpack' );
_x( 'Display links to your related content under posts and pages.', 'Module Description', 'jetpack' );
_x( 'keep visitors engaged on your blog by highlighting relevant and new content at the bottom of each published post.', 'Jumpstart Description', 'jetpack' );

// modules/sharedaddy.php
_x( 'Sharing', 'Module Name', 'jetpack' );
_x( 'Allow visitors to share your content on Facebook, Twitter, and more with a click.', 'Module Description', 'jetpack' );
_x( 'Twitter, Facebook and Google+ buttons at the bottom of each post, making it easy for visitors to share your content.', 'Jumpstart Description', 'jetpack' );

// modules/shortcodes.php
_x( 'Shortcode Embeds', 'Module Name', 'jetpack' );
_x( 'Embed content from YouTube, Vimeo, SlideShare, and more, no coding necessary.', 'Module Description', 'jetpack' );

// modules/shortlinks.php
_x( 'WP.me Shortlinks', 'Module Name', 'jetpack' );
_x( 'Enable WP.me-powered shortlinks for all posts and pages.', 'Module Description', 'jetpack' );

// modules/site-icon.php
_x( 'Site Icon', 'Module Name', 'jetpack' );
_x( 'Add a site icon to your site.', 'Module Description', 'jetpack' );

// modules/sso.php
_x( 'Jetpack Single Sign On', 'Module Name', 'jetpack' );
_x( 'Allow your users to log in using their WordPress.com accounts.', 'Module Description', 'jetpack' );
_x( 'lets you login to all your Jetpack-enabled sites with one click using your WordPress.com account.', 'Jumpstart Description', 'jetpack' );

// modules/stats.php
_x( 'WordPress.com Stats', 'Module Name', 'jetpack' );
_x( 'Monitor your stats with clear, concise reports and no additional load on your server.', 'Module Description', 'jetpack' );

// modules/subscriptions.php
_x( 'Subscriptions', 'Module Name', 'jetpack' );
_x( 'Allow users to subscribe to your posts and comments and receive notifications via email.', 'Module Description', 'jetpack' );
_x( 'give visitors two easy subscription options — while commenting, or via a separate email subscription widget you can display.', 'Jumpstart Description', 'jetpack' );

// modules/tiled-gallery.php
_x( 'Tiled Galleries', 'Module Name', 'jetpack' );
_x( 'Display your image galleries in a variety of sleek, graphic arrangements.', 'Module Description', 'jetpack' );

// modules/vaultpress.php
_x( 'VaultPress', 'Module Name', 'jetpack' );
_x( 'Protect your site with automatic backups and security scans. (Subscription required.)', 'Module Description', 'jetpack' );

// modules/verification-tools.php
_x( 'Site Verification', 'Module Name', 'jetpack' );
_x( 'Verify your site or domain with Google Webmaster Tools, Pinterest, and others.', 'Module Description', 'jetpack' );

// modules/videopress.php
_x( 'VideoPress', 'Module Name', 'jetpack' );
_x( 'Upload and embed videos right on your site. (Subscription required.)', 'Module Description', 'jetpack' );

// modules/widget-visibility.php
_x( 'Widget Visibility', 'Module Name', 'jetpack' );
_x( 'Specify which widgets appear on which pages of your site.', 'Module Description', 'jetpack' );

// modules/widgets.php
_x( 'Extra Sidebar Widgets', 'Module Name', 'jetpack' );
_x( 'Add images, Twitter streams, your site’s RSS links, and more to your sidebar.', 'Module Description', 'jetpack' );

// Modules with `Other` tag:
//  - modules/contact-form.php
//  - modules/notes.php
//  - modules/site-icon.php
_x( 'Other', 'Module Tag', 'jetpack' );

// Modules with `Writing` tag:
//  - modules/after-the-deadline.php
//  - modules/custom-content-types.php
//  - modules/enhanced-distribution.php
//  - modules/json-api.php
//  - modules/latex.php
//  - modules/markdown.php
//  - modules/post-by-email.php
//  - modules/shortcodes.php
_x( 'Writing', 'Module Tag', 'jetpack' );

// Modules with `Photos and Videos` tag:
//  - modules/carousel.php
//  - modules/photon.php
//  - modules/shortcodes.php
//  - modules/tiled-gallery.php
//  - modules/videopress.php
_x( 'Photos and Videos', 'Module Tag', 'jetpack' );

// Modules with `Social` tag:
//  - modules/comments.php
//  - modules/gravatar-hovercards.php
//  - modules/likes.php
//  - modules/publicize.php
//  - modules/sharedaddy.php
//  - modules/shortcodes.php
//  - modules/shortlinks.php
//  - modules/subscriptions.php
//  - modules/widgets.php
_x( 'Social', 'Module Tag', 'jetpack' );

// Modules with `Appearance` tag:
//  - modules/custom-css.php
//  - modules/gravatar-hovercards.php
//  - modules/infinite-scroll.php
//  - modules/minileven.php
//  - modules/photon.php
//  - modules/shortcodes.php
//  - modules/widget-visibility.php
//  - modules/widgets.php
_x( 'Appearance', 'Module Tag', 'jetpack' );

// Modules with `Developers` tag:
//  - modules/json-api.php
//  - modules/omnisearch.php
//  - modules/sso.php
_x( 'Developers', 'Module Tag', 'jetpack' );

// Modules with `Centralized Management` tag:
//  - modules/manage.php
_x( 'Centralized Management', 'Module Tag', 'jetpack' );

// Modules with `Recommended` tag:
//  - modules/manage.php
//  - modules/minileven.php
//  - modules/monitor.php
//  - modules/photon.php
//  - modules/protect.php
//  - modules/publicize.php
//  - modules/related-posts.php
//  - modules/sharedaddy.php
//  - modules/stats.php
_x( 'Recommended', 'Module Tag', 'jetpack' );

// Modules with `Mobile` tag:
//  - modules/minileven.php
_x( 'Mobile', 'Module Tag', 'jetpack' );

// Modules with `WordPress.com Stats` tag:
//  - modules/stats.php
_x( 'WordPress.com Stats', 'Module Tag', 'jetpack' );
