/* This file was automatically generated on Oct 06 2014 18:02:19 */

.slideshow-window {
	background-color: #222;
	border: 20px solid #222;
	border-radius: 11px;
	-moz-border-radius: 11px;
	-webkit-border-radius: 11px;
	-khtml-border-radius: 11px;
	margin-bottom: 20px;
	height: 410px;
	z-index: 1;
}

.slideshow-window.slideshow-white {
	background-color: #fff;
	border-color: #fff;
}

.slideshow-window, .slideshow-window * {
	-moz-box-sizing: content-box;
	-webkit-box-sizing: content-box;
	box-sizing: content-box;
}

.slideshow-loading {
	height: 100%;
	text-align: center;
	margin: auto;
}

body div.slideshow-window * img {
	/* Override any styles that might be present in the page stylesheet */
	border-width: 0 !important;
	margin-left: auto !important;
	margin-right: auto !important;
	padding: 0 !important;
	background-color: transparent !important;
	background-image: none !important;
	max-width: 100%;
}

.slideshow-loading img {
	vertical-align: middle;
}

.slideshow-slide {
	height: 100%;
	width: 100%;
	text-align: center;
	margin: auto;
	display: none;
}

.slideshow-slide img {
	vertical-align: middle;
}

.slideshow-line-height-hack {
	overflow: hidden;
	width: 0px;
	font-size: 0px;
}

.slideshow-slide-caption {
	font-size: 13px;
	font-family: "Helvetica Neue", sans-serif;
	color: #f7f7f7;
	text-shadow: #222 2px 1px 1px;
	line-height: 25px;
	height: 25px;
	position: absolute;
	bottom: 5px;
	right: 0;
	z-index: 100;
	width: 100%;
	text-align: center;
}

/* @noflip */
.slideshow-controls {
	z-index: 1000;
		position: absolute;
		bottom: 30px;
		margin: auto;
	text-align: center;
	width: 100%;
	-ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
	opacity: 0.5;
	direction:ltr;
}

body div div.slideshow-controls a,
body div div.slideshow-controls a:hover {
	border:2px solid rgba(255,255,255,0.1) !important;
	background-color: #000 !important;
	background-color: rgba(0,0,0,0.6) !important;
	background-image: url('../../img/slideshow-controls.png') !important;
	background-repeat: no-repeat;
	background-size: 142px 16px !important;
	background-position: -34px 8px !important;
	color: #222 !important;
	margin: 0 5px !important;
	padding: 0 !important;
	display: inline-block !important;
	*display: inline;
	zoom: 1;
	height: 32px !important;
	width: 32px !important;
	line-height: 32px !important;
	text-align: center !important;
	-khtml-border-radius: 10em !important;
	-webkit-border-radius: 10em !important;
	-moz-border-radius: 10em !important;
	border-radius: 10em !important;
	-webkit-transition: 300ms border-color ease-out;
	-moz-transition: 300ms border-color ease-out;
	-o-transition: 300ms border-color ease-out;
	transition: 300ms border-color ease-out;
}

@media only screen and (-webkit-min-device-pixel-ratio: 1.5) {
	body div div.slideshow-controls a,
	body div div.slideshow-controls a:hover {
		background-image: url('../../img/slideshow-controls-2x.png') !important;
	}
}

body div div.slideshow-controls a:hover {
	border-color: rgba(255,255,255,1) !important;
}

body div div.slideshow-controls a:first-child { background-position: -76px 8px !important;}
body div div.slideshow-controls a:last-child { background-position: -117px 8px !important;}
body div div.slideshow-controls a:nth-child(2) { background-position: -34px 8px !important;}
body div div.slideshow-controls a.running { background-position: -34px 8px !important;}
body div div.slideshow-controls a.paused { background-position: 9px 8px !important;}

.slideshow-controls a img {
	border: 50px dotted fuchsia;
}
