/* loads inline on wp-admin in order to reduce http requests */

#protect_dashboard_widget .inside {
	margin: 0;
	padding: 0;
	text-align: center;
}

.jetpack-security * {
	box-sizing: border-box;
}

/* alert msgs */
#protect_dashboard_widget .msg {
	color: #fff;
	text-align: center;
	padding: 10px;
}

#protect_dashboard_widget .msg.working {
	background: #7BAC48;
}

#protect_dashboard_widget .msg.attn {
	background: #d94f4f;
}

#protect_dashboard_widget .msg a {
	color: #fff;
	text-decoration: underline;
}

#protect_dashboard_widget .msg a:hover {
	text-decoration: none;
}

#protect_dashboard_widget .msg .dashicons {
	float: left;
	text-decoration: none;
	border-radius: 2px;
}

#protect_dashboard_widget .msg.working .dashicons {
	color: #609643;
}

#protect_dashboard_widget .msg.working .dashicons:hover {
	background: #609643;
	color: #7BAC48;
}

#protect_dashboard_widget .msg.attn .dashicons {
	color: #a93838;
}

#protect_dashboard_widget .msg.attn .dashicons:hover {
	background: #a93838;
	color: #d94f4f;
}

.blocked-attacks,
.file-scanning {
	position: relative;
}

.blocked-attacks {
	background: #fafafa;
	border-bottom: 1px #eee solid;
	padding-bottom: 35px;
}

.jetpack-security-sharing {
	width: 60px;
	display: inline-block;
	position: absolute;
	left: 0;
	top: 10px;
}

.jetpack-security-sharing a {
	color: #dcdcdc;
}

.jetpack-security-sharing a:hover {
	color: #cdcbcb;
}

.blocked-attacks h2,
.blocked-attacks h3 {
	color: #7BAC48;
	font-family: "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
	font-weight: 300;
}

.blocked-attacks h2 {
	font-size: 4em;
	line-height: 110%;
	margin: 0;
	padding: 10px 12px 10px 12px;
}

.blocked-attacks h3 {
	font-size: 1.1em;
	line-height: 110%;
	padding: 0 12px 10px 12px;
	margin: 0;
}

.jetpack-protect-logo {
	width: 50px;
	position: relative;
}

.file-scanning {
	margin-top: -30px;
	padding: 0 12px;
}