<?php
/**
 * Italy Provinces
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['IT'] = array(
	'AG' => __( 'Agrigento', 'woocommerce' ),
	'AL' => __( 'Alessandria', 'woocommerce' ),
	'AN' => __( 'Ancona', 'woocommerce' ),
	'AO' => __( 'Aosta', 'woocommerce' ),
	'AR' => __( 'Arezzo', 'woocommerce' ),
	'AP' => __( 'Ascoli Piceno', 'woocommerce' ),
	'AT' => __( 'Asti', 'woocommerce' ),
	'AV' => __( 'Avellino', 'woocommerce' ),
	'BA' => __( 'Bari', 'woocommerce' ),
	'BT' => __( 'Barletta-Andria-Trani', 'woocommerce' ),
	'BL' => __( 'Belluno', 'woocommerce' ),
	'BN' => __( 'Benevento', 'woocommerce' ),
	'BG' => __( 'Bergamo', 'woocommerce' ),
	'BI' => __( 'Biella', 'woocommerce' ),
	'BO' => __( 'Bologna', 'woocommerce' ),
	'BZ' => __( 'Bolzano', 'woocommerce' ),
	'BS' => __( 'Brescia', 'woocommerce' ),
	'BR' => __( 'Brindisi', 'woocommerce' ),
	'CA' => __( 'Cagliari', 'woocommerce' ),
	'CL' => __( 'Caltanissetta', 'woocommerce' ),
	'CB' => __( 'Campobasso', 'woocommerce' ),
	'CI' => __( 'Carbonia-Iglesias', 'woocommerce' ),
	'CE' => __( 'Caserta', 'woocommerce' ),
	'CT' => __( 'Catania', 'woocommerce' ),
	'CZ' => __( 'Catanzaro', 'woocommerce' ),
	'CH' => __( 'Chieti', 'woocommerce' ),
	'CO' => __( 'Como', 'woocommerce' ),
	'CS' => __( 'Cosenza', 'woocommerce' ),
	'CR' => __( 'Cremona', 'woocommerce' ),
	'KR' => __( 'Crotone', 'woocommerce' ),
	'CN' => __( 'Cuneo', 'woocommerce' ),
	'EN' => __( 'Enna', 'woocommerce' ),
	'FM' => __( 'Fermo', 'woocommerce' ),
	'FE' => __( 'Ferrara', 'woocommerce' ),
	'FI' => __( 'Firenze', 'woocommerce' ),
	'FG' => __( 'Foggia', 'woocommerce' ),
	'FC' => __( 'Forlì-Cesena', 'woocommerce' ),
	'FR' => __( 'Frosinone', 'woocommerce' ),
	'GE' => __( 'Genova', 'woocommerce' ),
	'GO' => __( 'Gorizia', 'woocommerce' ),
	'GR' => __( 'Grosseto', 'woocommerce' ),
	'IM' => __( 'Imperia', 'woocommerce' ),
	'IS' => __( 'Isernia', 'woocommerce' ),
	'SP' => __( 'La Spezia', 'woocommerce' ),
	'AQ' => __( 'L&apos;Aquila', 'woocommerce' ),
	'LT' => __( 'Latina', 'woocommerce' ),
	'LE' => __( 'Lecce', 'woocommerce' ),
	'LC' => __( 'Lecco', 'woocommerce' ),
	'LI' => __( 'Livorno', 'woocommerce' ),
	'LO' => __( 'Lodi', 'woocommerce' ),
	'LU' => __( 'Lucca', 'woocommerce' ),
	'MC' => __( 'Macerata', 'woocommerce' ),
	'MN' => __( 'Mantova', 'woocommerce' ),
	'MS' => __( 'Massa-Carrara', 'woocommerce' ),
	'MT' => __( 'Matera', 'woocommerce' ),
	'ME' => __( 'Messina', 'woocommerce' ),
	'MI' => __( 'Milano', 'woocommerce' ),
	'MO' => __( 'Modena', 'woocommerce' ),
	'MB' => __( 'Monza e della Brianza', 'woocommerce' ),
	'NA' => __( 'Napoli', 'woocommerce' ),
	'NO' => __( 'Novara', 'woocommerce' ),
	'NU' => __( 'Nuoro', 'woocommerce' ),
	'OT' => __( 'Olbia-Tempio', 'woocommerce' ),
	'OR' => __( 'Oristano', 'woocommerce' ),
	'PD' => __( 'Padova', 'woocommerce' ),
	'PA' => __( 'Palermo', 'woocommerce' ),
	'PR' => __( 'Parma', 'woocommerce' ),
	'PV' => __( 'Pavia', 'woocommerce' ),
	'PG' => __( 'Perugia', 'woocommerce' ),
	'PU' => __( 'Pesaro e Urbino', 'woocommerce' ),
	'PE' => __( 'Pescara', 'woocommerce' ),
	'PC' => __( 'Piacenza', 'woocommerce' ),
	'PI' => __( 'Pisa', 'woocommerce' ),
	'PT' => __( 'Pistoia', 'woocommerce' ),
	'PN' => __( 'Pordenone', 'woocommerce' ),
	'PZ' => __( 'Potenza', 'woocommerce' ),
	'PO' => __( 'Prato', 'woocommerce' ),
	'RG' => __( 'Ragusa', 'woocommerce' ),
	'RA' => __( 'Ravenna', 'woocommerce' ),
	'RC' => __( 'Reggio Calabria', 'woocommerce' ),
	'RE' => __( 'Reggio Emilia', 'woocommerce' ),
	'RI' => __( 'Rieti', 'woocommerce' ),
	'RN' => __( 'Rimini', 'woocommerce' ),
	'RM' => __( 'Roma', 'woocommerce' ),
	'RO' => __( 'Rovigo', 'woocommerce' ),
	'SA' => __( 'Salerno', 'woocommerce' ),
	'VS' => __( 'Medio Campidano', 'woocommerce' ),
	'SS' => __( 'Sassari', 'woocommerce' ),
	'SV' => __( 'Savona', 'woocommerce' ),
	'SI' => __( 'Siena', 'woocommerce' ),
	'SR' => __( 'Siracusa', 'woocommerce' ),
	'SO' => __( 'Sondrio', 'woocommerce' ),
	'TA' => __( 'Taranto', 'woocommerce' ),
	'TE' => __( 'Teramo', 'woocommerce' ),
	'TR' => __( 'Terni', 'woocommerce' ),
	'TO' => __( 'Torino', 'woocommerce' ),
	'OG' => __( 'Ogliastra', 'woocommerce' ),
	'TP' => __( 'Trapani', 'woocommerce' ),
	'TN' => __( 'Trento', 'woocommerce' ),
	'TV' => __( 'Treviso', 'woocommerce' ),
	'TS' => __( 'Trieste', 'woocommerce' ),
	'UD' => __( 'Udine', 'woocommerce' ),
	'VA' => __( 'Varese', 'woocommerce' ),
	'VE' => __( 'Venezia', 'woocommerce' ),
	'VB' => __( 'Verbano-Cusio-Ossola', 'woocommerce' ),
	'VC' => __( 'Vercelli', 'woocommerce' ),
	'VR' => __( 'Verona', 'woocommerce' ),
	'VV' => __( 'Vibo Valentia', 'woocommerce' ),
	'VI' => __( 'Vicenza', 'woocommerce' ),
	'VT' => __( 'Viterbo', 'woocommerce' )
);
