/**
 * Like Button toolbar button, loading text & container styles
 *
 * @todo: doesn't look like "style.css" is used anymore.
 */


/* Master container */
#jp-post-flair {
	padding-top: .5em;
}

/* Overall Sharedaddy block title */
div.sharedaddy,
#content div.sharedaddy,
#main div.sharedaddy {
	clear: both;
}

div.sharedaddy h3.sd-title {
	margin: 0 0 1em 0;
	display: inline-block;
	line-height: 1.2;
	font-size: 9pt;
	font-weight: bold;
}

div.sharedaddy h3.sd-title:before {
	content: "";
	display: block;
	width: 100%;
	min-width: 30px;
	border-top: 1px solid #ddd;
	margin-bottom: 1em;
}


/* Toolbar */
#wpadminbar li#wp-admin-bar-admin-bar-likes-widget {
	width: 61px;
	overflow: hidden;
}

#wpadminbar iframe.admin-bar-likes-widget {
	width: 61px;
	height: 28px;
	min-height: 28px;
	border-width: 0px;
	position: absolute;
	top: 0;
}

div.jetpack-likes-widget-wrapper {
	width: 100%;
	min-height: 50px;	/* Previous height, 60px */
	position: relative; /* Need to abs position placeholder and iframe so there isn't a jarring jump */
}

div.jetpack-likes-widget-wrapper .sd-link-color {
	font-size: 12px;
}

div.jetpack-likes-widget-wrapper.slim-likes-widget {
	width: 1px; /* initial default */
	min-height: 0;
}

#likes-other-gravatars {
	display: none;
	position: absolute;
	padding: 10px 10px 12px 10px;
	background-color: #2e4453;
	border-width: 0;
	box-shadow: 0 0 10px #2e4453;
	box-shadow: 0 0 10px rgba(46,68,83,.6);
	min-width: 130px;
	z-index: 1000;
}

#likes-other-gravatars * {
	line-height: normal;
}

#likes-other-gravatars .likes-text {
	color: white;
	font-size: 12px;
	padding-bottom: 8px;
}

#likes-other-gravatars ul,
#likes-other-gravatars li {
	margin: 0;
	padding: 0;
	text-indent: 0;
	list-style-type: none;
}

#likes-other-gravatars li::before {
	content: "";
}

#likes-other-gravatars ul.wpl-avatars {
	overflow: auto;
	display: block;
	max-height: 190px;
}

#likes-other-gravatars ul.wpl-avatars li {
	width: 32px;
	height: 32px;
	float: left;
	margin: 0 5px 5px 0;
}

#likes-other-gravatars ul.wpl-avatars li a {
	margin: 0 2px 0 0;
	border-bottom: none !important;
	display: block;
}

#likes-other-gravatars ul.wpl-avatars li a img {
	background: none;
	border: none;
	margin: 0 !important;
	padding: 0 !important;
	position: static;
}

div.sd-box {
	border-top: 1px solid #ddd;
	border-top: 1px solid rgba(0,0,0,.13);
}

.entry-content .post-likes-widget, .post-likes-widget,
.comment-likes-widget {
	margin: 0;
	border-width: 0;
	display: block;
}


/* Loading text */
.post-likes-widget-placeholder {
	margin: 0;
	border-width: 0;
	position: relative;
}

.post-likes-widget-placeholder .button {
	display: none;	/* Let's not show a dummy like button, let's just make a great button experience once it's loaded */
}

.post-likes-widget-placeholder .button span {
}

.post-likes-widget-placeholder .loading {
	color: #999;
	font-size: 12px;
}

.slim-likes-widget .post-likes-widget {
	width: auto;
	float: none;
}


/* Like Special cases (display on it's own) */
div.sharedaddy.sd-like-enabled .sd-like h3 {
	display: none;
}

div.sharedaddy.sd-like-enabled .sd-like .post-likes-widget {
	width: 100%;
	float: none;
	position: absolute; /* Need to abs position placeholder and iframe so there isn't a jarring jump */
	top: 0;
}

.comment-likes-widget {
	width: 100%;
}


/* Make ratings block. @todo: make !important unnecessary by removing inline style */
.pd-rating {
	display: block !important;
}


/* Hide G+ title */
.sd-gplus .sd-title {
	display: none;
}
