
#jetpack_summary_widget {
	* {
		box-sizing: border-box;
	}

	.inside {
		margin: 0;
		padding: 0;
		font-family: "proxima-nova", "Open Sans", Helvetica, Arial, sans-serif;
	}

	.stats,
	.widgets,
	.wpcom-connect {
		padding: .75em;
	}

	.wpcom-connect {
		background: #fafafa;
		text-align: center;

		.jp-emblem {
			padding: 5px 0 0 0;
		}

		svg {
			width: 40px;
			height: 40px;
			path {
				fill: $green;
			}
		}

		.jp-emblem,
		h3,
		p {
			width: 100%;
		}

		h3 {
			font-size: 1.25em;
			font-weight: 400;
		}

		p {
			color: #777;
			margin-top: 0;
			padding: 0 15px;
		}

		.actions {
			text-align: center;
			padding: 15px 0 10px 0;
			small {
				display: block;
				a {
					color: #999;
				}
			}
		}
	}

	.button-jetpack {
		@include button( $green );
	}

	footer {
		background: #fafafa;
		padding: .75em;
		overflow: hidden;
		border-top: 1px solid #ccc;

		.protect,
		.akismet {
			width: 50%;
			float: left;
			text-align: left;
		}

		h3 {
			font-size: 1.5em;
			font-weight: normal;
			margin: 0;
			padding: 0;
		}

		p {
			margin: 0;
			padding: 0;
		}

		section {
			margin: 0;
			padding: 0;
			text-align: center;
		}
	}
}