<?php
/**
 * Brazillian states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['BR'] = array(
	'AC' => __( 'Acre', 'woocommerce' ),
	'AL' => __( 'Alagoas', 'woocommerce' ),
	'AP' => __( 'Amap&aacute;', 'woocommerce' ),
	'AM' => __( 'Amazonas', 'woocommerce' ),
	'BA' => __( 'Bahia', 'woocommerce' ),
	'CE' => __( 'Cear&aacute;', 'woocommerce' ),
	'DF' => __( 'Distrito Federal', 'woocommerce' ),
	'ES' => __( 'Esp&iacute;rito Santo', 'woocommerce' ),
	'GO' => __( 'Goi&aacute;s', 'woocommerce' ),
	'MA' => __( 'Maranh&atilde;o', 'woocommerce' ),
	'MT' => __( 'Mato Grosso', 'woocommerce' ),
	'MS' => __( 'Mato Grosso do Sul', 'woocommerce' ),
	'MG' => __( 'Minas Gerais', 'woocommerce' ),
	'PA' => __( 'Par&aacute;', 'woocommerce' ),
	'PB' => __( 'Para&iacute;ba', 'woocommerce' ),
	'PR' => __( 'Paran&aacute;', 'woocommerce' ),
	'PE' => __( 'Pernambuco', 'woocommerce' ),
	'PI' => __( 'Piau&iacute;', 'woocommerce' ),
	'RJ' => __( 'Rio de Janeiro', 'woocommerce' ),
	'RN' => __( 'Rio Grande do Norte', 'woocommerce' ),
	'RS' => __( 'Rio Grande do Sul', 'woocommerce' ),
	'RO' => __( 'Rond&ocirc;nia', 'woocommerce' ),
	'RR' => __( 'Roraima', 'woocommerce' ),
	'SC' => __( 'Santa Catarina', 'woocommerce' ),
	'SP' => __( 'S&atilde;o Paulo', 'woocommerce' ),
	'SE' => __( 'Sergipe', 'woocommerce' ),
	'TO' => __( 'Tocantins', 'woocommerce' )
);
