<?php
/**
 * Greek Regions
 *
 * @author   WooThemes
 * @category i18n
 * @package  WooCommerce/i18n
 * @version  2.3.0
 */
global $states;

$states['GR'] = array(
	'I' => __( 'Αττική', 'woocommerce' ),
	'A' => __( 'Ανατολική Μακεδονία και Θράκη', 'woocommerce' ),
	'B' => __( 'Κεντρική Μακεδονία', 'woocommerce' ),
	'C' => __( 'Δυτική Μακεδονία', 'woocommerce' ),
	'D' => __( 'Ήπειρος', 'woocommerce' ),
	'E' => __( 'Θεσσαλία', 'woocommerce' ),
	'F' => __( 'Ιόνιοι Νήσοι', 'woocommerce' ),
	'G' => __( 'Δυτική Ελλάδα', 'woocommerce' ),
	'H' => __( 'Στερεά Ελλάδα', 'woocommerce' ),
	'J' => __( 'Πελοπόννησος', 'woocommerce' ),
	'K' => __( 'Βόρειο Αιγαίο', 'woocommerce' ),
	'L' => __( 'Νότιο Αιγαίο', 'woocommerce' ),
	'M' => __( 'Κρήτη', 'woocommerce' )
);
