<?php
/**
 * Canadian states
 *
 * @author      WooThemes
 * @category    i18n
 * @package     WooCommerce/i18n
 * @version     2.0.0
 */
global $states;

$states['CA'] = array(
	'AB' => __( 'Alberta', 'woocommerce' ),
	'BC' => __( 'British Columbia', 'woocommerce' ),
	'MB' => __( 'Manitoba', 'woocommerce' ),
	'NB' => __( 'New Brunswick', 'woocommerce' ),
	'NL' => __( 'Newfoundland and Labrador', 'woocommerce' ),
	'NT' => __( 'Northwest Territories', 'woocommerce' ),
	'NS' => __( 'Nova Scotia', 'woocommerce' ),
	'NU' => __( 'Nunavut', 'woocommerce' ),
	'ON' => __( 'Ontario', 'woocommerce' ),
	'PE' => __( 'Prince Edward Island', 'woocommerce' ),
	'QC' => __( 'Quebec', 'woocommerce' ),
	'SK' => __( 'Saskatchewan', 'woocommerce' ),
	'YT' => __( 'Yukon Territory', 'woocommerce' )
);
