/**
 * WooCommerce CSS Variables
 */

$woocommerce:   	#a46497;
$green:         	#7ad03a;
$red:           	#a00;
$orange:        	#ffba00;
$blue:          	#2ea2cc;

$primary:           #a46497;                                    // Primary colour for buttons (alt)
$primarytext:       desaturate(lighten($primary, 50%), 18%);    // Text on primary colour bg

$secondary:         desaturate(lighten($primary, 40%), 21%);    // Secondary buttons
$secondarytext:     desaturate(darken($secondary, 60%), 21%);   // Text on secondary colour bg

$highlight:         adjust-hue($primary, 150deg);               // Prices, In stock labels, sales flash
$highlightext:      desaturate(lighten($highlight, 50%), 18%);  // Text on highlight colour bg

$contentbg:         #fff;                                       // Content BG - Tabs (active state)
$subtext:           #777;                                       // small, breadcrumbs etc