/* =Infinity Styles
-------------------------------------------------------------- */
.infinite-scroll #main:after {
	clear: both;
	content: '';
	display: block;
}
.infinite-scroll #content {
	margin-bottom: 40px;
}
.infinite-scroll.neverending #content {
	margin-bottom: 70px;
}
.infinite-scroll .infinite-wrap {
	border-top: none;
	padding-top: 0;
}
.infinite-scroll .infinite-wrap .hentry:last-child {
	border-bottom: 1px solid #ddd;
}
.infinite-scroll .infinite-wrap:last-of-type .hentry:last-child {
	border-bottom: none;
}

/**
 * Elements to hide:
 * (footer widgets, post navigation, regular footer)
 */
.infinite-scroll.neverending #colophon #supplementary,
.infinite-scroll #nav-below,
.infinite-scroll.neverending #colophon {
	display: none;
}

/* Hooks to infinity-end body class to restore footer */
.infinity-end.neverending #colophon {
	display: block;
}

/* For responsive CSS */
@media (max-width: 800px) {
	.infinite-scroll #infinite-handle {
		padding-bottom: 40px;
	}
}